==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-settings/src/main/java/org/apache/maven/settings/RuntimeInfo.java <==
package org.apache.maven.settings;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import java.io.File;

/**
 * To handle runtime informations like local repository or profiles.
 *
 */
@Deprecated
public class RuntimeInfo
{
    @SuppressWarnings( "checkstyle:constantname" )
    public static final String userHome = System.getProperty( "user.home" );

    @SuppressWarnings( "checkstyle:constantname" )
    public static final File userMavenConfigurationHome = new File( userHome, ".m2" );

    public static final File DEFAULT_USER_SETTINGS_FILE = new File( userMavenConfigurationHome, "settings.xml" );

    private File settings;

    public RuntimeInfo()
    {
        this.settings = DEFAULT_USER_SETTINGS_FILE;
    }

    public RuntimeInfo( File settings )
    {
        this.settings = settings;
    }

    public File getFile()
    {
        return settings;
    }
}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-settings/src/main/java/org/apache/maven/settings/RuntimeInfo.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.settings;

import java.io.File;

/**
 * To handle runtime informations like local repository or profiles.
 *
 */
@Deprecated
public class RuntimeInfo {
    @SuppressWarnings("checkstyle:constantname")
    public static final String userHome = System.getProperty("user.home");

    @SuppressWarnings("checkstyle:constantname")
    public static final File userMavenConfigurationHome = new File(userHome, ".m2");

    public static final File DEFAULT_USER_SETTINGS_FILE = new File(userMavenConfigurationHome, "settings.xml");

    private File settings;

    public RuntimeInfo() {
        this.settings = DEFAULT_USER_SETTINGS_FILE;
    }

    public RuntimeInfo(File settings) {
        this.settings = settings;
    }

    public File getFile() {
        return settings;
    }
}
